bl_info = {
    'name': 'Export MakeHuman weights to Json file',
    'author': 'BLP based on Blender templates',
    'version': (0,1),
    "blender": (2, 79, 0),
    'location': "File > Export > Export MakeHuman Weights",
    'description': 'Export MakeHuman weights as a Json file',
    'warning': '',
    'wiki_url': 'http://makehumancommunity.org/forum/',
    'category': 'MakeHuman'}

import bpy
from .SaveJson import saveJson
from .LoadJson import loadJson
from collections import OrderedDict

# ImportHelper is a helper class, defines filename and
# invoke() function which calls the file selector.
from bpy_extras.io_utils import ImportHelper
from bpy.props import StringProperty, BoolProperty, EnumProperty
from bpy.types import Operator

class ImportWeights(Operator, ImportHelper):
    bl_idname = "import.mhweights"
    bl_label = "Import MakeHuman Weights"

    # ImportHelper mixin class uses this
    filename_ext = ".mhw"

    filter_glob = StringProperty(
            default="*.mhw",
            options={'HIDDEN'},
            maxlen=255,  # Max internal buffer length, longer would be clamped.
            )

    def execute(self, context):
        print("Loading MakeHuman weights from: %s" % self.filepath)
        struct = loadJson(self.filepath)
        struct = struct["weights"]
        for key in struct.keys() :
            print("Json group: %s" % key)
            ng = context.active_object.vertex_groups.new(key)
            for i in range(len(struct[key])) :
                ng.add([struct[key][i][0]], struct[key][i][1], 'REPLACE')

        #for i in range(len(struct["groups"])) :
        #    print("Json group: %s" % struct["groups"][i]["group"])
        #    ng = context.active_object.vertex_groups.new(struct["groups"][i]["group"])
        #    weights = struct["groups"][i]["weights"]
        #    for w in weights:
        #        ng.add([w[0]], w[1], 'REPLACE') 

        return {'FINISHED'}

# ExportHelper is a helper class, defines filename and
# invoke() function which calls the file selector.
from bpy_extras.io_utils import ExportHelper


class ExportWeights(Operator, ExportHelper):
    """This appears in the tooltip of the operator and in the generated docs"""
    bl_idname = "export.mhweights"  # important since its how bpy.ops.import_test.weights is constructed
    bl_label = "Export MakeHuman Weights"

    # ExportHelper mixin class uses this
    filename_ext = ".mhw"

    filter_glob = StringProperty(
            default="*.mhw",
            options={'HIDDEN'},
            maxlen=255,  # Max internal buffer length, longer would be clamped.
            )

    def execute(self, context):
        object = context.active_object
        print("Saving MakeHuman weights for object %s" % object.name)
        vgroups = dict([(vgroup.index, (vgroup.name, [])) for vgroup in object.vertex_groups])
        for v in object.data.vertices:
            for g in v.groups:
                vgroups[g.group][1].append((v.index, g.weight))
        struct = OrderedDict()
        struct2 = OrderedDict()
        struct["weights"] = struct2
        for key in vgroups.keys():
            struct2[vgroups[key][0]] = vgroups[key][1]

        saveJson(struct, self.filepath)
        print("Saving weights completed")
        return {'FINISHED'}


# Only needed if you want to add into a dynamic menu
def menu_func_export(self, context):
    self.layout.operator(ExportWeights.bl_idname, text="Export MakeHuman Weights")

def menu_func_import(self, context):
    self.layout.operator(ImportWeights.bl_idname, text="Import MakeHuman Weights")

def register():
    bpy.utils.register_class(ExportWeights)
    bpy.types.INFO_MT_file_export.append(menu_func_export)
    bpy.utils.register_class(ImportWeights)
    bpy.types.INFO_MT_file_import.append(menu_func_import)


def unregister():
    bpy.utils.unregister_class(ExportWeights)
    bpy.types.INFO_MT_file_export.remove(menu_func_export)
    bpy.utils.unregister_class(ImportWeights)
    bpy.types.INFO_MT_file_import.remove(menu_func_import)

if __name__ == "__main__":
    register()

    # test call
    bpy.ops.export.weights('INVOKE_DEFAULT')
